@@ -18,6 +18,10 @@
  "vietnamese-viqr" "Vietnamese" 'quail-use-package
  "VQ" "Vietnamese input method with VIQR mnemonic system"
  "quail/viqr")
+(register-input-method
+ "vietnamese-telex" "Vietnamese" 'quail-use-package
+ "VT" "Vietnamese telex input method"
+ "quail/vntelex")
 (register-input-method
  "chinese-cns-tsangchi" "Chinese-CNS" 'quail-use-package
  "$(GT?(BC" "$(GDcEFrSD+!JT?on!K(BCNS"
@@ -235,6 +239,22 @@ There are two dead keys on `=' and `+'.  Characters with diaresis are
 accessible through `+='.
 All other keys are the same as on standard US keyboard."
  "quail/czech")
+(register-input-method
+ "slovak" "Slovak" #'quail-use-package
+ "SK" "Standard Slovak keyboard."
+ "quail/slovak")
+(register-input-method
+ "slovak-prog-1" "Slovak" #'quail-use-package
+ "SK" "Slovak (non-standard) keyboard for programmers #1."
+ "quail/slovak")
+(register-input-method
+ "slovak-prog-2" "Slovak" #'quail-use-package
+ "SK" "Slovak (non-standard) keyboard for programmers #2."
+ "quail/slovak")
+(register-input-method
+ "slovak-prog-3" "Slovak" #'quail-use-package
+ "SK" "Slovak (non-standard) keyboard for programmers #3."
+ "quail/slovak")
 (register-input-method
  "turkish-postfix" "Latin-3" 'quail-use-package
  "TR<" "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers"
@@ -287,6 +307,10 @@ All other keys are the same as on standard US keyboard."
  "english-dvorak" "English" 'quail-use-package
  "DV@" "English (ASCII) input method simulating Dvorak keyboard"
  "quail/latin-post")
+(register-input-method
+ "rot13" "English" #'quail-use-package
+ "r13" "ROT-13 input method for English.  "
+ "quail/latin-alt")
 (register-input-method
  "latin-1-alt-postfix" "Latin-1" 'quail-use-package
  "1<" "Latin-1 character input method with postfix modifiers"
@@ -362,28 +386,55 @@ All other keys are the same as on standard US keyboard."
 
 (if (not (and (fboundp 'decode-char) (decode-char 'ucs #x31C)
               (eq #x31C (encode-char (decode-char 'ucs #x31C) 'ucs))))
+    ;; We're on 21.4; use the non-UTF-8 IPA input method.
     (register-input-method
      "ipa" "IPA" 'quail-use-package
      "IPA"
      "International Phonetic Alphabet for English, French, German and Italian"
      "quail/ipa")
-
+  ;; We're in 21.5; make those input methods available that require UTF-8
+  ;; support.
   (register-input-method
    "kirshenbaum-ipa" "IPA" 'quail-use-package
    "IPA-K"
    "International Phonetic Alphabet, Kirshenbaum ASCII transliteration."
-   "quail/ipa-21.5")
+   "ipa-21.5")
   (register-input-method
    "x-sampa-ipa" "IPA" 'quail-use-package
    "IPA-S"
    "International Phonetic Alphabet, X-SAMPA ASCII transliteration."
-   "quail/ipa-21.5")
+   "ipa-21.5")
   (register-input-method
    "ipa" "IPA" 'quail-use-package
    "IPA"
    "International Phonetic Alphabet for English, French, German and Italian"
-   "quail/ipa-21.5"))
-
+   "ipa-21.5")
+  (register-input-method
+   "georgian" "Georgian" #'quail-use-package
+   (string (decode-char 'ucs #x10D2))
+   "A common Georgian transliteration (using Unicode)"
+   "georgian")
+  (register-input-method
+   "TeX" "UTF-8" 'quail-use-package
+   "\\" "LaTeX-like input method for many characters."
+   "latin-ltx")
+  (register-input-method
+   "rfc1345" "UTF-8" 'quail-use-package
+   "m"
+   "Unicode characters input method using RFC1345 mnemonics (non-ASCII only)."
+   "rfc1345")
+  (register-input-method
+   "sgml" "UTF-8" 'quail-use-package
+   "&" "Unicode characters input method using SGML entities."
+   "sgml-input")
+  (register-input-method
+   "welsh" "Welsh" 'quail-use-package
+   "$(D*q(B" "Welsh postfix input method, using Unicode"
+   "welsh")
+  (register-input-method
+   "cyrillic-tajik" "Cyrillic" 'quail-use-package
+   ",L6(Bt" "Transliterated keyboard layout optimized for Tajik."
+   "cyrillic-tajik"))
 (register-input-method
  "korean-hanja" "Korean" 'quail-use-package
  "$(C9zyS(B" "2$(C9z=D(BKSC$(CySm.(B: $(Cz1SWGO4B(B $(CySm.@G(B $(Cj$@;(B $(CGQ1[(B2$(C9zcR@87N(B $(C{<usGO?)(B $(C`TwI(B"
@@ -496,6 +547,10 @@ All other keys are the same as on standard US keyboard."
  "chinese-etzy" "Chinese-BIG5" 'quail-use-package
  "$(06/0D(B" "$(0&d'GTT&,!J6/'30D5x!K(B"
  "quail/ETZY")
+(register-input-method
+ "ethiopic" "Ethiopic" 'quail-use-package
+ (quote ("$(3$Q#U!.(B " (ethio-prefer-ascii-space "_" "$(3$h(B") (ethio-prefer-ascii-punctuation "." "$(3$i(B"))) "  Quail package for Ethiopic (Tigrigna and Amharic)"
+ "quail/ethiopic")
 (register-input-method
  "chinese-ecdict" "Chinese-BIG5" 'quail-use-package
  "$(05CKH(B" "$(0&d'GTT&,!J5CKH[0.)!K(B"
@@ -503,7 +558,7 @@ All other keys are the same as on standard US keyboard."
 (register-input-method
  "chinese-ctlaub" "Chinese-BIG5" 'quail-use-package
  "$(0N,Gn(B" "$(0KH)tTT&,!(N,Tg>A*#Gn5x!((B"
- "quail/CTLauB")
+ "quail/CTLau-b5")
 (register-input-method
  "chinese-ctlau" "Chinese-GB" 'quail-use-package
  "$AAuTA(B" "$A::WVJdHk!KAuN}OiJ=TARt!K(B"
@@ -520,6 +575,10 @@ All other keys are the same as on standard US keyboard."
  "chinese-4corner" "Chinese-BIG5" 'quail-use-package
  "$(0(?-F(B" "$(0(?-FHAP#(B:: "
  "quail/4Corner")
+(register-input-method
+ "chinese-sisheng" "Chinese" 'quail-use-package
+ "$(D+o(B" "S,Al(Bsh,D:(Bng input method for p,Do(Bny,Do(Bn transliteration of Chinese."
+ "quail/sisheng")
 (register-input-method
  "croatian" "Croatian" 'quail-use-package
  "HR" "\"Standard\" Croatian keyboard."
